@@ -24,10 +24,11 @@ sub do_config_GNU {
     my $config = File::Spec->catfile('config_autoconf.h');
     my $log = File::Spec->catfile('config_autoconf.log');
 
+    my $ac = Config::AutoConf->new(logfile => $log);
+
     print STDERR "...\n";
     print STDERR "... GNU REGEX configuration\n";
-    print STDERR "...\n";
-    my $ac = Config::AutoConf->new(logfile => $log);
+    print STDERR "... -----------------------\n";
     $ac->check_cc;
     $ac->check_default_headers;
     ac_c_inline($ac);
@@ -36,7 +37,12 @@ sub do_config_GNU {
     $ac->check_func('malloc', { prologue => '#include <stdlib.h>' });
     $ac->check_func('realloc', { prologue => '#include <stdlib.h>' });
     $ac->check_type('mbstate_t', { prologue => "#include <stddef.h>\n#include <stdio.h>\n#include <time.h>\n#include <wchar.h>" });
+    $ac->check_type('_Bool');
+    $ac->check_header('wchar.h');
     $ac->check_header('wctype.h');
+    $ac->check_header('stdbool.h');
+    $ac->check_header('stdint.h');
+    $ac->check_header('sys/int_types.h');
     #
     # No test on alloca -> HAVE_ALLOCA will be false, which is what we want
     #
@@ -45,6 +51,7 @@ sub do_config_GNU {
     $ac->check_decl('isblank', { action_on_true => sub { $ac->define_var('HAVE_DECL_ISBLANK', 1) }, prologue => '#include <ctype.h>' });
     $ac->define_var('_REGEX_INCLUDE_LIMITS_H', 1);
     $ac->define_var('_REGEX_LARGE_OFFSETS', 1);
+    $ac->define_var('RE_ENABLE_I18N', 1);
     $ac->define_var('re_syntax_options', 'rpl_re_syntax_options');
     $ac->define_var('re_set_syntax', 'rpl_re_set_syntax');
     $ac->define_var('re_compile_pattern', 'rpl_re_compile_pattern');
@@ -60,6 +67,13 @@ sub do_config_GNU {
     $ac->define_var('regexec', 'rpl_regexec');
     $ac->define_var('regerror', 'rpl_regerror');
     $ac->define_var('regfree', 'rpl_regfree');
+    $ac->check_type('size_t');
+    $ac->check_type('ssize_t');
+    $ac->check_sizeof_type('size_t');
+    $ac->check_sizeof_type('short');
+    $ac->check_sizeof_type('int');
+    $ac->check_sizeof_type('long');
+    $ac->check_sizeof_type('long long');
     $ac->write_config_h($config);
 }
 
